@@ -10,7 +10,7 @@ use Text::Soundex;
 use strict;
 
 use vars qw($VERSION);
-$VERSION = '0.02';
+$VERSION = '0.03';
 
 use GedNav::Individual;
 
@@ -376,7 +376,7 @@ probably come in a separate lump, when the time comes.
 
 =head1 AUTHOR
 
-Rob Fugina, robf@geeks.com
+Rob Fugina, robf@fugina.com
 
 =head1 SEE ALSO
 
